from radiant.framework.server import RadiantAPI, RadiantServer, render
from .figurestream import FigureStream


########################################################################
class FrameworkAPI(RadiantAPI):
    """"""


FrameworkServer = None

